@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # -*- encoding:utf-8 -*-
 import os,stat
 import sys
@@ -57,6 +58,8 @@ def startproject(proj_name=''):
     os.mkdir(sub_proj_dir)
     shutil.move(path_join('__init__.py'),sub_proj_dir)
     shutil.move(path_join('views'),sub_proj_dir)
+    shutil.move(path_join('static'),sub_proj_dir)
+    shutil.move(path_join('templates'),sub_proj_dir)
     os.chmod(path_join('manage.py'),
              os.stat(path_join('manage.py')).st_mode |
              stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)
